@@ -210,7 +210,7 @@ AsyncBackend <- R6::R6Class("AsyncBackend",
             }, args = list(capture))
         },
 
-        # Run tasks on the cluster in the session asynchronously.
+        # Run tasks asynchronously via the cluster in the session.
         .sapply = function(x, fun, ...) {
             # Capture the `...`.
             dots <- list(...)
@@ -225,6 +225,36 @@ AsyncBackend <- R6::R6Class("AsyncBackend",
             }, args = list(x, fun, dots))
         },
 
+        # Run tasks asynchronously via the cluster in the session.
+        .lapply = function(x, fun, ...) {
+            # Capture the `...`.
+            dots <- list(...)
+
+            # Perform the evaluation from the `R` session.
+            private$.cluster$call(function(x, fun, dots) {
+                # Run the task.
+                output <- do.call(parallel::parLapply, c(list(cluster, x, fun), dots))
+
+                # Return to the session.
+                return(output)
+            }, args = list(x, fun, dots))
+        },
+
+        # Run tasks asynchronously via the cluster in the session.
+        .apply = function(x, margin, fun, ...) {
+            # Capture the `...`.
+            dots <- list(...)
+
+            # Perform the evaluation from the `R` session.
+            private$.cluster$call(function(x, margin, fun, dots) {
+                # Run the task.
+                output <- do.call(parallel::parApply, c(list(cluster, x, margin, fun), dots))
+
+                # Return to the session.
+                return(output)
+            }, args = list(x, margin, fun, dots))
+        },
+
         # Clear the current output on the backend.
         .clear_output = function() {
             # Clear output.
@@ -233,8 +263,17 @@ AsyncBackend <- R6::R6Class("AsyncBackend",
 
         # Set the output based on the session read.
         .set_output = function() {
-            # Store the relevant results from the output.
-            private$.output <- private$.cluster$read()$result
+            # Get all session output.
+            output <- private$.cluster$read()
+
+            # If an error ocurred in the session.
+            if (!is.null(output$error)) {
+                # Throw error in the main session.
+                Exception$async_task_error(output$error)
+            }
+
+            # Otherwise, store the relevant results from the output.
+            private$.output <- output$result
         },
 
         # Get the current task state (i.e., what is happening in the session).
@@ -424,10 +463,9 @@ AsyncBackend <- R6::R6Class("AsyncBackend",
         },
 
         #' @description
-        #' Run a task on the backend akin to [parallel::parSapply()].
+        #' Run a task on the backend akin to [`parallel::parSapply()`].
         #'
-        #' @param x A vector (i.e., usually of integers) to pass to the `fun`
-        #' function.
+        #' @param x An atomic vector or list to pass to the `fun` function.
         #'
         #' @param fun A function to apply to each element of `x`.
         #'
@@ -445,6 +483,59 @@ AsyncBackend <- R6::R6Class("AsyncBackend",
             private$.sapply(x, fun, ...)
         },
 
+        #' @description
+        #' Run a task on the backend akin to [`parallel::parLapply()`].
+        #'
+        #' @param x An atomic vector or list to pass to the `fun` function.
+        #'
+        #' @param fun A function to apply to each element of `x`.
+        #'
+        #' @param ... Additional arguments to pass to the `fun` function.
+        #'
+        #' @return
+        #' This method returns void. The output of the task execution must be
+        #' stored in the private field `.output` on the [`parabar::Backend`]
+        #' abstract class, and is accessible via the `get_output()` method.
+        lapply = function(x, fun, ...) {
+            # Throw if backend is busy.
+            private$.throw_if_backend_is_busy()
+
+            # Deploy the task asynchronously.
+            private$.lapply(x, fun, ...)
+        },
+
+        #' @description
+        #' Run a task on the backend akin to [`parallel::parApply()`].
+        #'
+        #' @param x An array to pass to the `fun` function.
+        #'
+        #' @param margin A numeric vector indicating the dimensions of `x` the
+        #' `fun` function should be applied over. For example, for a matrix,
+        #' `margin = 1` indicates applying `fun` rows-wise, `margin = 2`
+        #' indicates applying `fun` columns-wise, and `margin = c(1, 2)`
+        #' indicates applying `fun` element-wise. Named dimensions are also
+        #' possible depending on `x`. See [`parallel::parApply()`] and
+        #' [`base::apply()`] for more details.
+        #'
+        #' @param fun A function to apply to `x` according to the `margin`.
+        #'
+        #' @param ... Additional arguments to pass to the `fun` function.
+        #'
+        #' @return
+        #' This method returns void. The output of the task execution must be
+        #' stored in the private field `.output` on the [`parabar::Backend`]
+        #' abstract class, and is accessible via the `get_output()` method.
+        apply = function(x, margin, fun, ...) {
+            # Throw if backend is busy.
+            private$.throw_if_backend_is_busy()
+
+            # Validate provided margins.
+            Helper$check_array_margins(margin, dim(x))
+
+            # Deploy the task asynchronously.
+            private$.apply(x, margin, fun, ...)
+        },
+
         #' @description
         #' Get the output of the task execution.
         #'
@@ -466,8 +557,10 @@ AsyncBackend <- R6::R6Class("AsyncBackend",
         #' task is still running.
         #'
         #' @return
-        #' A vector or list of the same length as `x` containing the results of
-        #' the `fun`. It resembles the format of [base::sapply()].
+        #' A vector, matrix, or list of the same length as `x`, containing the
+        #' results of the `fun`. The output format differs based on the specific
+        #' operation employed. Check out the documentation for the `apply`
+        #' operations of [`parallel::parallel`] for more information.
         get_output = function(wait = FALSE) {
             # Reset the output on exit.
             on.exit({
