@@ -83,12 +83,21 @@
 #'
 #' @export
 Context <- R6::R6Class("Context",
+    inherit = Service,
+
     private = list(
         # The backend used by the context manager.
         .backend = NULL
     ),
 
     public = list(
+        #' @description
+        #' Create a new [`parabar::Context`] object.
+        #'
+        #' @return
+        #' An object of class [`parabar::Context`].
+        initialize = function() { invisible() },
+
         #' @description
         #' Set the backend instance to be used by the context.
         #'
@@ -155,12 +164,17 @@ Context <- R6::R6Class("Context",
         #' @param variables A character vector of variable names to export.
         #'
         #' @param environment An environment object from which to export the
-        #' variables.
+        #' variables. Defaults to the parent frame.
         #'
         #' @return This method returns void.
         export = function(variables, environment) {
+            # If no environment is provided.
+            if (missing(environment)) {
+                # Use the caller's environment where the variables are defined.
+                environment <- parent.frame()
+            }
+
             # Consume the backend API.
-            # TODO: Check that this works as expected (i.e., the environment).
             private$.backend$export(variables, environment)
         },
 
@@ -183,10 +197,9 @@ Context <- R6::R6Class("Context",
         },
 
         #' @description
-        #' Run a task on the backend akin to [parallel::parSapply()].
+        #' Run a task on the backend akin to [`parallel::parSapply()`].
         #'
-        #' @param x A vector (i.e., usually of integers) to pass to the `fun`
-        #' function.
+        #' @param x An atomic vector or list to pass to the `fun` function.
         #'
         #' @param fun A function to apply to each element of `x`.
         #'
@@ -201,6 +214,50 @@ Context <- R6::R6Class("Context",
             private$.backend$sapply(x = x, fun = fun, ...)
         },
 
+        #' @description
+        #' Run a task on the backend akin to [`parallel::parLapply()`].
+        #'
+        #' @param x An atomic vector or list to pass to the `fun` function.
+        #'
+        #' @param fun A function to apply to each element of `x`.
+        #'
+        #' @param ... Additional arguments to pass to the `fun` function.
+        #'
+        #' @return
+        #' This method returns void. The output of the task execution must be
+        #' stored in the private field `.output` on the [`parabar::Backend`]
+        #' abstract class, and is accessible via the `get_output()` method.
+        lapply = function(x, fun, ...) {
+            # Consume the backend API.
+            private$.backend$lapply(x = x, fun = fun, ...)
+        },
+
+        #' @description
+        #' Run a task on the backend akin to [`parallel::parApply()`].
+        #'
+        #' @param x An array to pass to the `fun` function.
+        #'
+        #' @param margin A numeric vector indicating the dimensions of `x` the
+        #' `fun` function should be applied over. For example, for a matrix,
+        #' `margin = 1` indicates applying `fun` rows-wise, `margin = 2`
+        #' indicates applying `fun` columns-wise, and `margin = c(1, 2)`
+        #' indicates applying `fun` element-wise. Named dimensions are also
+        #' possible depending on `x`. See [`parallel::parApply()`] and
+        #' [`base::apply()`] for more details.
+        #'
+        #' @param fun A function to apply to `x` according to the `margin`.
+        #'
+        #' @param ... Additional arguments to pass to the `fun` function.
+        #'
+        #' @return
+        #' This method returns void. The output of the task execution must be
+        #' stored in the private field `.output` on the [`parabar::Backend`]
+        #' abstract class, and is accessible via the `get_output()` method.
+        apply = function(x, margin, fun, ...) {
+            # Consume the backend API.
+            private$.backend$apply(x = x, margin = margin, fun = fun, ...)
+        },
+
         #' @description
         #' Get the output of the task execution.
         #'
@@ -217,8 +274,10 @@ Context <- R6::R6Class("Context",
         #' task.
         #'
         #' @return
-        #' A vector or list of the same length as `x` containing the results of
-        #' the `fun`. It resembles the format of [base::sapply()].
+        #' A vector, matrix, or list of the same length as `x`, containing the
+        #' results of the `fun`. The output format differs based on the specific
+        #' operation employed. Check out the documentation for the `apply`
+        #' operations of [`parallel::parallel`] for more information.
         get_output = function(...) {
             # Consume the backend API.
             private$.backend$get_output(...)
